const {
  readdir,
  readFileSync,
  writeFileSync,
  statSync,
} = require('fs');
const { copy } = require('fs-extra');
const { join } = require('path');
const os = require('os');

const updatePackageJson = (path, { name }) => {
  const pkgJsonPath = join(path, 'package.json');
  const pkgJSON = JSON.parse(readFileSync(pkgJsonPath).toString());
  pkgJSON.name = name;
  pkgJSON.author = 'yourname';
  pkgJSON.version = '1.0.0';
  writeFileSync(pkgJsonPath, JSON.stringify(pkgJSON, null, 2));
};

exports.onInstalled = ({ path }) =>
  new Promise((resolve) => {
    resolve(true);
  });

exports.onLogin = async (context) => {
  return false;
};

exports.onOpen = () => false;

exports.onCreate = async (context) => {
  const { path, name, scaffold } = context;
  const scaffoldPath = join(__dirname, 'templates/umi', 'scaffolds', scaffold);
  await copy(scaffoldPath, path, {
    preserveTimestamps: true,
    filter: src => src.indexOf('.gitkeep') === -1 && src.indexOf('.DS_Store') === -1,
  });
  updatePackageJson(path, { name });
  return true;
};

exports.onTemplates = () =>
  new Promise(async (resolve, reject) => {
    const filterType = 'umi';
    const realDir = join(__dirname, `./templates/${filterType}/scaffolds`);
    readdir(realDir, (e, dirs) => {
      if (e) reject(e);
      const exts = [];
      (dirs || []).forEach((dir) => {
        if (statSync(join(realDir, dir)).isFile()) {
          return null;
        }
        exts.push({
          title: '空白模板',
          type: dir,
          path: `file://${join(realDir, dir)}`,
          snapshot: `file://${join(realDir, dir, 'snapshot.png')}`,
        });
      });
      resolve(exts);
    });
  });
