import path from 'path';
import webpack from 'webpack';
import ExtractTextPlugin from 'extract-text-webpack-plugin';

const thirdPart = [
  'vscode',
  'tea',
  'superagent',
  'electron',
  'internal-ip',
  'vinyl-fs',
  'gulp-tar',
  'gulp-gzip',
  'gulp-chmod',
  'gulp-rename',
];

module.exports = {
  entry: {
    index: './src/index',
  },
  output: {
    filename: '[name].js',
    path: path.resolve('./lib/'),
    libraryTarget: 'umd',
  },
  externals(context, request, callback) {
    if (thirdPart.indexOf(request) > -1) {
      callback(null, request);
    } else {
      callback(null, false);
    }
  },
  module: {
    loaders: [
      {
        exclude: [
          /\.html$/,
          /\.(js|jsx)$/,
          /\.(css|less)$/,
          /\.json$/,
          /\.svg$/,
        ],
        use: [
          {
            loader: require.resolve('url-loader'),
            options: {
              limit: 10000,
              name: 'static/[name].[hash:8].[ext]',
            },
          },
        ],
      },
      {
        test: /\.js?$/,
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: ['es2015', 'stage-0', 'react'],
            plugins: [
              ['import', { libraryName: 'antd', style: 'css' }],
            ],
          },
        },
      },
      {
        test: /\.css$/,
        use: ExtractTextPlugin.extract({
          fallback: 'style-loader',
          use: ['css-loader?modules=true&localIdentName=[local]___[hash:base64:7]'],
        }),
      },
      {
        test: /\.less/,
        use: ExtractTextPlugin.extract({
          fallback: require.resolve('style-loader'),
          use: [
            {
              loader: require.resolve('css-loader'),
              options: {
                importLoaders: 2,
                modules: true,
                localIdentName: '[local]___[hash:base64:7]',
              },
            },
            {
              loader: require.resolve('less-loader'),
              options: {
                modifyVars: {
                  'tooltip-arrow-color': '#4C537D',
                  'tooltip-bg': '#4C537D',

                  'primary-color': '#75B0FF',
                  'body-background': '#222747',
                  'component-background': '#222747',
                  'background-color-base': '#222747',
                  'heading-color': 'rgba(255,255,255,1)',
                  'text-color': 'rgba(255,255,255,0.8)',
                  'disabled-color': 'rgba(255,255,255,0.25)',
                  'shadow-color': 'rgba(255,255,255,0.2)',
                  'border-color-base': '#3E456B',
                  'border-color-split': '#3E456B',
                  'border-radius-base': '0px',
                  'shadow-1-up': 'none',
                  'shadow-1-down': 'none',
                  'shadow-1-left': 'none',
                  'shadow-1-right': 'none',
                  'shadow-2': 'none',
                  'input-bg': '#222747',
                  'input-placeholder-color': 'rgba(255,255,255,0.45)',
                  'tabs-card-head-background': '#222747',
                  'popover-bg': '#3E456B',
                  'btn-default-color': '#75B0FF',

                  'select-color': 'rgba(23, 28, 55, 1)',
                  'hover-color': 'rgba(23, 28, 55, .6)',
                  'text-icon-color': 'rgba(255, 255, 255, .8)',
                  'text-active-color': 'rgba(255, 255, 255, 1)',
                  'active-color': '#75B0FF',
                  'default-color': '#1B213E',
                  'popover-color': '#fff',
                  'popover-active-color': '#31385A',
                  'popover-spliter-color': '#222847',

                  'sidebar-bg': '#31385a',
                  'sidebar-hover-color': '#75B0FF',

                  'status-bar-font-color': 'text-color',
                  'status-bar-bg': '#171C37',

                  'file-tree-bg': '#222747',
                  'editor-tab-bg': '#293052',
                  'editor-tab-active-bg': '#1B213E',
                  'sim-bg': '#222747',
                  'sim-tab-bg': '#31385A',
                  'sim-tab-active-bg': '#222847',
                  'box-shadow-bottom': '0 1px 4px 0 rgba(0,0,0,0.30)',
                  'log-bg': '#3E456B',
                  'editor-bg': '#1B213E',
                },
              },
            },
          ],
        }),
      },
    ],
  },
  plugins: [
    new ExtractTextPlugin({
      filename: '[name].css',
    }),
    new webpack.DefinePlugin({
      $dirname: '__dirname',
    }),
  ],
  target: 'node',
  node: {
    __dirname: true,
  },
};
